import { CacheMetadata, Context } from './common';
export declare type GetFreshValueStartEvent = {
    name: 'getFreshValueStart';
};
export declare type GetFreshValueHookPendingEvent = {
    name: 'getFreshValueHookPending';
};
export declare type GetFreshValueSuccessEvent<Value> = {
    name: 'getFreshValueSuccess';
    value: Value;
};
export declare type GetFreshValueErrorEvent = {
    name: 'getFreshValueError';
    error: unknown;
};
export declare type GetFreshValueCacheFallbackEvent = {
    name: 'getFreshValueCacheFallback';
    value: unknown;
};
export declare type CheckFreshValueErrorEvent<Value> = {
    name: 'checkFreshValueError';
    reason: string;
};
export declare type WriteFreshValueSuccessEvent<Value> = {
    name: 'writeFreshValueSuccess';
    metadata: CacheMetadata;
    /**
     * Value might not actually be written to cache in case getting fresh
     * value took longer then ttl */
    written: boolean;
    migrated: boolean;
};
export declare type WriteFreshValueErrorEvent = {
    name: 'writeFreshValueError';
    error: unknown;
};
export declare type GetCachedValueStartEvent = {
    name: 'getCachedValueStart';
};
export declare type GetCachedValueReadEvent = {
    name: 'getCachedValueRead';
    entry: unknown;
};
export declare type GetCachedValueEmptyEvent = {
    name: 'getCachedValueEmpty';
};
export declare type GetCachedValueOutdatedEvent = {
    name: 'getCachedValueOutdated';
    value: unknown;
    metadata: CacheMetadata;
};
export declare type GetCachedValueSuccessEvent<Value> = {
    name: 'getCachedValueSuccess';
    value: Value;
    migrated: boolean;
};
export declare type CheckCachedValueErrorEvent = {
    name: 'checkCachedValueError';
    reason: string;
};
export declare type GetCachedValueErrorEvent = {
    name: 'getCachedValueError';
    error: unknown;
};
export declare type RefreshValueStartEvent = {
    name: 'refreshValueStart';
};
export declare type RefreshValueSuccessEvent<Value> = {
    name: 'refreshValueSuccess';
    value: Value;
};
export declare type RefreshValueErrorEvent = {
    name: 'refreshValueError';
    error: unknown;
};
export declare type CacheEvent<Value> = GetFreshValueStartEvent | GetFreshValueHookPendingEvent | GetFreshValueSuccessEvent<Value> | GetFreshValueErrorEvent | GetFreshValueCacheFallbackEvent | CheckFreshValueErrorEvent<Value> | WriteFreshValueSuccessEvent<Value> | WriteFreshValueErrorEvent | GetCachedValueStartEvent | GetCachedValueReadEvent | GetCachedValueEmptyEvent | GetCachedValueOutdatedEvent | GetCachedValueSuccessEvent<Value> | CheckCachedValueErrorEvent | GetCachedValueErrorEvent | RefreshValueStartEvent | RefreshValueSuccessEvent<Value> | RefreshValueErrorEvent;
export declare type Reporter<Value> = (event: CacheEvent<Value>) => void;
export declare type CreateReporter<Value> = (context: Omit<Context<Value>, 'report'>) => Reporter<Value>;
interface ReporterOpts {
    formatDuration?: (ms: number) => string;
    logger?: Pick<typeof console, 'log' | 'warn' | 'error'>;
    performance?: Pick<typeof Date, 'now'>;
}
export declare function verboseReporter<Value>({ formatDuration, logger, performance, }?: ReporterOpts): CreateReporter<Value>;
export {};
